@@ -1,13 +1,15 @@
--- MySQL dump 10.9
+-- MySQL dump 10.13  Distrib 5.6.17, for linux-glibc2.5 (x86_64)
 --
--- Host: cabot    Database: ensemblgenomes_ontology_39_73
+-- Host: localhost    Database: ensemblgenomes_ontology_45_79
 -- ------------------------------------------------------
--- Server version	5.1.51
+-- Server version	5.6.17
 
 /*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
 /*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
 /*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
 /*!40101 SET NAMES utf8 */;
+/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
+/*!40103 SET TIME_ZONE='+00:00' */;
 /*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='' */;
 /*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;
 
@@ -16,15 +18,20 @@
 --
 
 DROP TABLE IF EXISTS `synonym`;
+/*!40101 SET @saved_cs_client     = @@character_set_client */;
+/*!40101 SET character_set_client = utf8 */;
 CREATE TABLE `synonym` (
   `synonym_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
   `term_id` int(10) unsigned NOT NULL,
   `name` text NOT NULL,
+  `type` enum('EXACT','BROAD','NARROW','RELATED') DEFAULT NULL,
   PRIMARY KEY (`synonym_id`),
   UNIQUE KEY `term_synonym_idx` (`term_id`,`synonym_id`),
   KEY `name_idx` (`name`(50))
-) ENGINE=MyISAM AUTO_INCREMENT=391363 DEFAULT CHARSET=latin1 CHECKSUM=1;
+) ENGINE=MyISAM AUTO_INCREMENT=155472 DEFAULT CHARSET=latin1 CHECKSUM=1;
+/*!40101 SET character_set_client = @saved_cs_client */;
 
+/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;
 
 /*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
 /*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
@@ -32,3 +39,4 @@ CREATE TABLE `synonym` (
 /*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
 /*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;
 
+-- Dump completed on 2015-03-31 17:33:35
